summaryrefslogtreecommitdiffstats
path: root/service/system/logger_service/server/src/ss_logger_util.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'service/system/logger_service/server/src/ss_logger_util.cpp')
-rwxr-xr-xservice/system/logger_service/server/src/ss_logger_util.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/service/system/logger_service/server/src/ss_logger_util.cpp b/service/system/logger_service/server/src/ss_logger_util.cpp
index 6ac7225..0de6022 100755
--- a/service/system/logger_service/server/src/ss_logger_util.cpp
+++ b/service/system/logger_service/server/src/ss_logger_util.cpp
@@ -1019,8 +1019,8 @@ EFrameworkunifiedStatus CLoggerUtil::CopyUntyped(std::string f_source,
} else if (0 != S_ISDIR(l_stat.st_mode)) {
l_eStatus = CopyDirectory(f_source, f_destination);
} else if (0 != S_ISLNK(l_stat.st_mode)) {
- // avoid duplicate copy for eErrorEventTypeInterfaceunifiedEmmcLogs: /nv/log/awlog -> /nv/BS/ss/logger_service/rwdata/log2/awlog
- if (f_source.find("/nv/BS/ss/logger_service/rwdata/awlog") == std::string::npos) {
+ // avoid duplicate copy for eErrorEventTypeInterfaceunifiedEmmcLogs: /var/local/lib/basesystem/nv/log/awlog -> /nv/BS/ss/logger_service/rwdata/log2/awlog
+ if (f_source.find("/var/local/lib/basesystem/nv/BS/ss/logger_service/rwdata/awlog") == std::string::npos) {
l_eStatus = CopyDirectory(f_source, f_destination);
}
} else if (0 != S_ISREG(l_stat.st_mode)) {